@@ -16,7 +16,6 @@
 # limitations under the License.
 
 import os
-import six
 import subprocess
 import sys
 
@@ -40,10 +39,7 @@ def pip_execute(*args, **kwargs):
             from pip import main as _pip_execute
         except ImportError:
             apt_update()
-            if six.PY2:
-                apt_install('python-pip')
-            else:
-                apt_install('python3-pip')
+            apt_install('python3-pip')
             from pip import main as _pip_execute
         _pip_execute(*args, **kwargs)
     finally:
@@ -140,12 +136,8 @@ def pip_list():
 
 def pip_create_virtualenv(path=None):
     """Create an isolated Python environment."""
-    if six.PY2:
-        apt_install('python-virtualenv')
-        extra_flags = []
-    else:
-        apt_install(['python3-virtualenv', 'virtualenv'])
-        extra_flags = ['--python=python3']
+    apt_install(['python3-virtualenv', 'virtualenv'])
+    extra_flags = ['--python=python3']
 
     if path:
         venv_path = path
