@@ -137,8 +137,8 @@ class ApplyPlaybookTestCases(unittest.TestCase):
         charmhelpers.contrib.ansible.apply_playbook(
             'playbooks/dependencies.yaml')
 
-        self.mock_subprocess.check_call.assert_called_once_with([
-            'ansible-playbook', '-c', 'local', 'playbooks/dependencies.yaml'],
+        self.mock_subprocess.check_output.assert_called_once_with([
+            'ansible-playbook', '-vvv', '-c', 'local', 'playbooks/dependencies.yaml'],
             env={'PYTHONUNBUFFERED': '1'})
 
     def test_writes_vars_file(self):
@@ -196,8 +196,8 @@ class ApplyPlaybookTestCases(unittest.TestCase):
         charmhelpers.contrib.ansible.apply_playbook(
             'playbooks/complete-state.yaml', tags=['install', 'somethingelse'])
 
-        self.mock_subprocess.check_call.assert_called_once_with([
-            'ansible-playbook', '-c', 'local', 'playbooks/complete-state.yaml',
+        self.mock_subprocess.check_output.assert_called_once_with([
+            'ansible-playbook', '-vvv', '-c', 'local', 'playbooks/complete-state.yaml',
             '--tags', 'install,somethingelse'], env={'PYTHONUNBUFFERED': '1'})
 
     @mock.patch.object(hookenv, 'config')
@@ -206,8 +206,8 @@ class ApplyPlaybookTestCases(unittest.TestCase):
             'playbooks/complete-state.yaml', tags=['install', 'somethingelse'],
             extra_vars={'a': 'b'})
 
-        self.mock_subprocess.check_call.assert_called_once_with([
-            'ansible-playbook', '-c', 'local', 'playbooks/complete-state.yaml',
+        self.mock_subprocess.check_output.assert_called_once_with([
+            'ansible-playbook', '-vvv', '-c', 'local', 'playbooks/complete-state.yaml',
             '--tags', 'install,somethingelse', '--extra-vars', '{"a": "b"}'],
             env={'PYTHONUNBUFFERED': '1'})
 
@@ -217,8 +217,8 @@ class ApplyPlaybookTestCases(unittest.TestCase):
             'playbooks/complete-state.yaml', tags=['install', 'somethingelse'],
             extra_vars='@myvars.json')
 
-        self.mock_subprocess.check_call.assert_called_once_with([
-            'ansible-playbook', '-c', 'local', 'playbooks/complete-state.yaml',
+        self.mock_subprocess.check_output.assert_called_once_with([
+            'ansible-playbook', '-vvv', '-c', 'local', 'playbooks/complete-state.yaml',
             '--tags', 'install,somethingelse', '--extra-vars', '"@myvars.json"'],
             env={'PYTHONUNBUFFERED': '1'})
 
@@ -228,8 +228,8 @@ class ApplyPlaybookTestCases(unittest.TestCase):
             'playbooks/complete-state.yaml', tags=['install', 'somethingelse'],
             extra_vars={'pkg': {'a': 'present', 'b': 'absent'}})
 
-        self.mock_subprocess.check_call.assert_called_once_with([
-            'ansible-playbook', '-c', 'local', 'playbooks/complete-state.yaml',
+        self.mock_subprocess.check_output.assert_called_once_with([
+            'ansible-playbook', '-vvv', '-c', 'local', 'playbooks/complete-state.yaml',
             '--tags', 'install,somethingelse', '--extra-vars',
             '{"pkg": {"a": "present", "b": "absent"}}'],
             env={'PYTHONUNBUFFERED': '1'})
@@ -243,8 +243,8 @@ class ApplyPlaybookTestCases(unittest.TestCase):
         hooks.execute(['foo'])
 
         self.assertEqual(foo.call_count, 1)
-        self.mock_subprocess.check_call.assert_called_once_with([
-            'ansible-playbook', '-c', 'local', 'my/playbook.yaml',
+        self.mock_subprocess.check_output.assert_called_once_with([
+            'ansible-playbook', '-vvv', '-c', 'local', 'my/playbook.yaml',
             '--tags', 'foo'], env={'PYTHONUNBUFFERED': '1'})
 
     @mock.patch.object(hookenv, 'config')
@@ -254,8 +254,8 @@ class ApplyPlaybookTestCases(unittest.TestCase):
 
         hooks.execute(['start'])
 
-        self.mock_subprocess.check_call.assert_called_once_with([
-            'ansible-playbook', '-c', 'local', 'my/playbook.yaml',
+        self.mock_subprocess.check_output.assert_called_once_with([
+            'ansible-playbook', '-vvv', '-c', 'local', 'my/playbook.yaml',
             '--tags', 'start'], env={'PYTHONUNBUFFERED': '1'})
 
 
